﻿using System;
using CoreGraphics;
using CoreText;
using Foundation;
using Syncfusion.SfChart.iOS;
using UIKit;

namespace SimpleSample
{
	public class CustomBehavior : SFChartBehavior
	{
		public CustomBehavior()
		{
			Color = UIColor.Green;
			LineWidth = 2.0f;
		}

		public double YValue
		{
			get;
			set;
		}

		public double XValue
		{
			get;
			set;
		}

		public UIColor Color
		{
			get;
			set;
		}

		public nfloat LineWidth
		{
			get;
			set;
		}

		public override void DrawInContext(CoreGraphics.CGContext ctx)
		{
			if (Chart != null)
			{
				if (Chart.SecondaryAxis != null)
				{
					CGRect seriesClipRect = Chart.SeriesClipRect;

					double yvalue = Chart.PointForValue(YValue, Chart.SecondaryAxis);
					nfloat xvalue = (nfloat)Chart.PointForValue(XValue, Chart.PrimaryAxis);
					nfloat TickLength = Chart.SecondaryAxis.MajorTickStyle.LineSize.NFloatValue;

					//Draw Line
					ctx.SaveState();
					ctx.SetStrokeColor(Color.CGColor);
					ctx.SetLineWidth(LineWidth);
					ctx.MoveTo(seriesClipRect.X,(nfloat)yvalue);
					ctx.AddLineToPoint(seriesClipRect.GetMaxX()+ TickLength,(nfloat)yvalue);
					ctx.StrokePath();
					ctx.RestoreState();

					//Draw Arrow Triangle
					ctx.SaveState();
					ctx.SetFillColor(Color.CGColor);
					ctx.MoveTo(xvalue-40,(nfloat)yvalue);
					ctx.AddLineToPoint(xvalue, (nfloat)yvalue-20);
					ctx.AddLineToPoint(xvalue +40, (nfloat)yvalue);
					ctx.AddLineToPoint(xvalue-40, (nfloat)yvalue);
					ctx.FillPath();
					ctx.RestoreState();

					string label = YValue.ToString((Chart.SecondaryAxis.LabelStyle.LabelFormatter as NSNumberFormatter).PositiveFormat);

					UIFont font = Chart.SecondaryAxis.LabelStyle.Font;
					CGSize size = label.StringSize(font);
					size = new CGSize(size.Width + 8, size.Height + 8);

					CGPoint startPoint = new CGPoint(seriesClipRect.GetMaxX() + TickLength, (nfloat)yvalue - size.Height / 2);

					//Draw the Text background.
					ctx.SaveState();
					ctx.SetStrokeColor(Color.CGColor);
					ctx.SetLineWidth(LineWidth);
					ctx.SetFillColor(UIColor.White.CGColor);
					ctx.FillRect(new CGRect(startPoint, size));
					ctx.AddRect(new CGRect(startPoint, size));
					ctx.StrokePath();
					ctx.FillPath();
					ctx.RestoreState();

					NSString str = new NSString(label);

					var attributes = new UIStringAttributes
					{
						ForegroundColor = UIColor.Green,
						Font =font
					};

					//Draw the text
					str.DrawString(new CGPoint(startPoint.X + 4, startPoint.Y + 4),attributes);

				}
			}
		}
	}
}
