﻿using System;
using Foundation;
using Syncfusion.SfChart.iOS;
using UIKit;

namespace SimpleSample
{
	public partial class ViewController : UIViewController
	{
		ChartDataModel dataModel;
		SFChart chart;


		protected ViewController(IntPtr handle) : base(handle)
		{
			// Note: this .ctor should not contain any initialization logic.
		}

		public override void ViewDidLoad()
		{
			base.ViewDidLoad();


			chart = new SFChart();
			chart.Frame = this.View.Frame;

			SFCategoryAxis primaryAxis = new SFCategoryAxis();
			primaryAxis.Title.Text = new NSString("Month");
			chart.PrimaryAxis = primaryAxis;

			//Adding Secondary Axis for the Chart.
			SFNumericalAxis secondaryAxis = new SFNumericalAxis();
			secondaryAxis.LabelStyle.Font = UIFont.SystemFontOfSize(14);
			secondaryAxis.OpposedPosition = true;
			secondaryAxis.Title.Text = new NSString("Temperature");
			chart.SecondaryAxis = secondaryAxis;

			dataModel = new ChartDataModel();
			chart.DataSource = dataModel as SFChartDataSource;


			chart.AddChartBehavior(new CustomBehavior() { YValue = 120, XValue = 3});

			//Adding our Chart as a sub view.
			this.View.AddSubview(chart);


			// Perform any additional setup after loading the view, typically from a nib.
		}

		public override void DidReceiveMemoryWarning()
		{
			base.DidReceiveMemoryWarning();
			// Release any cached data, images, etc that aren't in use.
		}
	}

	public class ChartDataModel : SFChartDataSource
	{
		public NSMutableArray DataPoints;
		public SFChartDataPoint data;
		NSCalendar calendar;

		public ChartDataModel()
		{
			DataPoints = new NSMutableArray();
			calendar = new NSCalendar(NSCalendarType.Gregorian);

			NSDateComponents components = new NSDateComponents();
			components.Year = 2017;
			components.Month = 1;
			components.Day = 17;
			components.Hour = 0;
			components.Minute = 0;
			components.Second = 0;

			NSDate date = calendar.DateFromComponents(components);

			SFChartDataPoint numericPoints = new SFChartDataPoint(NSObject.FromObject(date), NSObject.FromObject(115), NSObject.FromObject(125),
												 NSObject.FromObject(70), NSObject.FromObject(90));
			DataPoints.Add(numericPoints);

			NSDateComponents datecomp = new NSDateComponents();
			datecomp.Month = 1;
			date = calendar.DateByAddingComponents(datecomp, date, NSCalendarOptions.None);
			numericPoints = new SFChartDataPoint(NSObject.FromObject(date), NSObject.FromObject(120), NSObject.FromObject(150),
				NSObject.FromObject(60), NSObject.FromObject(70));
			DataPoints.Add(numericPoints);

			date = calendar.DateByAddingComponents(datecomp, date, NSCalendarOptions.None);
			numericPoints = new SFChartDataPoint(NSObject.FromObject(date), NSObject.FromObject(160), NSObject.FromObject(200),
				NSObject.FromObject(140), NSObject.FromObject(190));
			DataPoints.Add(numericPoints);

			date = calendar.DateByAddingComponents(datecomp, date, NSCalendarOptions.None);
			numericPoints = new SFChartDataPoint(NSObject.FromObject(date), NSObject.FromObject(140), NSObject.FromObject(160),
				NSObject.FromObject(90), NSObject.FromObject(110));
			DataPoints.Add(numericPoints);

			date = calendar.DateByAddingComponents(datecomp, date, NSCalendarOptions.None);
			numericPoints = new SFChartDataPoint(NSObject.FromObject(date), NSObject.FromObject(180), NSObject.FromObject(200),
				NSObject.FromObject(100), NSObject.FromObject(120));
			DataPoints.Add(numericPoints);

			date = calendar.DateByAddingComponents(datecomp, date, NSCalendarOptions.None);
			numericPoints = new SFChartDataPoint(NSObject.FromObject(date), NSObject.FromObject(70), NSObject.FromObject(100),
				NSObject.FromObject(45), NSObject.FromObject(50));
			DataPoints.Add(numericPoints);

		}

		public override SFChartDataPoint GetDataPoint(SFChart chart, nint index, nint seriesIndex)
		{
			return DataPoints.GetItem<SFChartDataPoint>((nuint)index);
		}

		public override nint GetNumberOfDataPoints(SFChart chart, nint index)
		{
			return (int)DataPoints.Count;
		}

		public override SFSeries GetSeries(SFChart chart, nint index)
		{

			SFCandleSeries series = new SFCandleSeries();
			series.EnableAnimation = true;
			return series;
		}

		public override nint NumberOfSeriesInChart(SFChart chart)
		{
			return 1;
		}

	}
}
